==> haskell-lpeg-1.1.0-16-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-lpeg.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 lpeg
version:              1.1.0
visibility:           public
id:                   lpeg-1.1.0-BcG3lRJzGUvBV1ePy8tVZO
key:                  lpeg-1.1.0-BcG3lRJzGUvBV1ePy8tVZO
license:              MIT
copyright:
    © 2007-2019 Lua.org, PUC-Rio;
    © 2021-2023 Albert Krewinkel

maintainer:           Albert Krewinkel <tarleb@hslua.org>
author:               Albert Krewinkel
homepage:             https://hslua.org/
synopsis:             LPeg – Parsing Expression Grammars For Lua
description:
    This package contains the C sources of LPeg, as well
    as some tiny Haskell helper to load the package.

    <http://www.inf.puc-rio.br/~roberto/lpeg/>

category:             Foreign
abi:                  94fcb6d46683abc2dc4ee31b1d842e5c
exposed:              True
exposed-modules:      Lua.LPeg
import-dirs:          /usr/lib/ghc-9.4.8/site-local/lpeg-1.1.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/lpeg-1.1.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/lpeg-1.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-lpeg
hs-libraries:         HSlpeg-1.1.0-BcG3lRJzGUvBV1ePy8tVZO
depends:              base-4.17.2.1 lua-2.3.3-ICQ3CQuk32V3rnx60jB8Sm
haddock-interfaces:   /usr/share/doc/haskell-lpeg/html/lpeg.haddock
haddock-html:         /usr/share/doc/haskell-lpeg/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-lpeg-1.1.0-17-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-lpeg.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 lpeg
version:              1.1.0
visibility:           public
id:                   lpeg-1.1.0-13GftkYNKqpDIQ4zRIEs3l
key:                  lpeg-1.1.0-13GftkYNKqpDIQ4zRIEs3l
license:              MIT
copyright:
    © 2007-2019 Lua.org, PUC-Rio;
    © 2021-2023 Albert Krewinkel

maintainer:           Albert Krewinkel <tarleb@hslua.org>
author:               Albert Krewinkel
homepage:             https://hslua.org/
synopsis:             LPeg – Parsing Expression Grammars For Lua
description:
    This package contains the C sources of LPeg, as well
    as some tiny Haskell helper to load the package.

    <http://www.inf.puc-rio.br/~roberto/lpeg/>

category:             Foreign
abi:                  52a67916f5b46808c2cf462e141cdab4
exposed:              True
exposed-modules:      Lua.LPeg
import-dirs:          /usr/lib/ghc-9.4.8/site-local/lpeg-1.1.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/lpeg-1.1.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/lpeg-1.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-lpeg
hs-libraries:         HSlpeg-1.1.0-13GftkYNKqpDIQ4zRIEs3l
depends:              base-4.17.2.1 lua-2.3.3-BgRAgJ2P7mXKQm7WHLbp4Q
haddock-interfaces:   /usr/share/doc/haskell-lpeg/html/lpeg.haddock
haddock-html:         /usr/share/doc/haskell-lpeg/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
